# pylint:disable=C0111
from .reader import CCtiReader, MODE_AUTO, MODE_MEMORY

__all__ = [
    "CCtiReader",
	"MODE_AUTO",
	"MODE_MEMORY"
]

__version__ = "0.0.7"
__author__ = "AISpera"
__license__ = "Apache License, Version 2.0"